@@ -32,13 +32,16 @@
 #include "dot2qtconsts.h"
 #include "dotgraphview.h"
 #include "FontsCache.h"
+#include "kgraphviewerlib_debug.h"
 
-#include <KAction>
+#include <QAction>
 
 #include <QPainter>
 #include <QGraphicsSceneMouseEvent>
 #include <QMenu>
 
+#include <klocalizedstring.h>
+
 #include <iostream>
 
 //
@@ -57,36 +60,42 @@ CanvasEdge::CanvasEdge(DotGraphView* view, GraphEdge* e,
     m_scaleX(scaleX), m_scaleY(scaleY),
     m_xMargin(xMargin), m_yMargin(yMargin),
     m_gh(/*gh*/0), m_wdhcf(wdhcf), m_hdvcf(hdvcf), m_edge(e),
-    m_font(0), m_view(view), m_popup(new QMenu())
+    m_font(nullptr), m_view(view), m_popup(new QMenu())
 {
-  kDebug() << "edge "  << edge()->fromNode()->id() << "->"  << edge()->toNode()->id() << m_gh;
+  Q_UNUSED(gh);
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "edge "  << edge()->fromNode()->id() << "->"  << edge()->toNode()->id() << m_gh;
   setBoundingRegionGranularity(0.9);
   m_font = FontsCache::changeable().fromName(e->fontName());
 
   computeBoundingRect();
-//   kDebug() << "boundingRect computed: " << m_boundingRect;
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << "boundingRect computed: " << m_boundingRect;
   
   QString tipStr = i18n("%1 -> %2\nlabel='%3'",
       edge()->fromNode()->id(),edge()->toNode()->id(),e->label());
   setToolTip(tipStr);
 
   // the message should be given (or possible to be given) by the part user
-  KAction* removeEdgeAction = new KAction(i18n("Remove selected edge(s)"), this);
+  QAction* removeEdgeAction = new QAction(i18n("Remove selected edge(s)"), this);
   m_popup->addAction(removeEdgeAction);
-  connect(removeEdgeAction,SIGNAL(triggered(bool)),this,SLOT(slotRemoveEdge()));
+  connect(removeEdgeAction, &QAction::triggered,
+          this, &CanvasEdge::slotRemoveEdge);
   
   
-  connect(e,SIGNAL(changed()),this,SLOT(modelChanged()));
-  connect(this, SIGNAL(selected(CanvasEdge*,Qt::KeyboardModifiers)), view, SLOT(slotEdgeSelected(CanvasEdge*,Qt::KeyboardModifiers)));
+  connect(e, &GraphEdge::changed,
+          this, &CanvasEdge::modelChanged);
+  connect(this, &CanvasEdge::selected,
+          view, &DotGraphView::slotEdgeSelected);
   
-  connect(this, SIGNAL(edgeContextMenuEvent(QString,QPoint)), view, SLOT(slotContextMenuEvent(QString,QPoint)));
+  connect(this, &CanvasEdge::edgeContextMenuEvent,
+          view, &DotGraphView::slotContextMenuEvent);
 
   setAcceptHoverEvents ( true );
 
-  kDebug() << "connect slotElementHoverEnter";
-  connect(this, SIGNAL(hoverEnter(CanvasEdge*)), view, SLOT(slotElementHoverEnter(CanvasEdge*)));
-  connect(this, SIGNAL(hoverLeave(CanvasEdge*)), view, SLOT(slotElementHoverLeave(CanvasEdge*)));
-  
+  qCDebug(KGRAPHVIEWERLIB_LOG) << "connect slotElementHoverEnter";
+  connect(this, &CanvasEdge::hoverEnter,
+          view, static_cast<void(DotGraphView::*)(CanvasEdge*)>(&DotGraphView::slotElementHoverEnter));
+  connect(this, &CanvasEdge::hoverLeave,
+          view, static_cast<void(DotGraphView::*)(CanvasEdge*)>(&DotGraphView::slotElementHoverLeave));
 } 
 
 CanvasEdge::~CanvasEdge()
@@ -102,7 +111,7 @@ QRectF CanvasEdge::boundingRect() const
 
 QPainterPath CanvasEdge::shape () const
 {
-//   kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id();
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id();
 
   if (!m_shape.isEmpty()) {
     return m_shape;
@@ -127,7 +136,7 @@ QPainterPath CanvasEdge::pathForSpline(int splineNum, const DotRenderOp& dro) co
   for (int i = 0; i < dro.integers[0]; i++)
   {
     // computing of diffX and diffY to draw parallel edges
-    // when asked through the corresponding GraphViz feature
+    // when asked through the corresponding Graphviz feature
     qreal nom = (dro.integers[2*dro.integers[0]]-dro.integers[2]);
     qreal denom = (dro.integers[2*dro.integers[0]-1]-dro.integers[1]);
     qreal diffX, diffY;
@@ -160,7 +169,7 @@ QPainterPath CanvasEdge::pathForSpline(int splineNum, const DotRenderOp& dro) co
         (m_gh-dro.integers[2*i+2]/*%m_hdvcf*/)*m_scaleY + m_yMargin + diffY
     );
     points[i] = p;
-//     kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id()  << p;
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id()  << p;
   }
 
   QPainterPath path;
@@ -176,7 +185,7 @@ QPainterPath CanvasEdge::pathForSpline(int splineNum, const DotRenderOp& dro) co
 void CanvasEdge::paint(QPainter* p, const QStyleOptionGraphicsItem* option,
                    QWidget* widget)
 {
-//   kDebug();
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
 Q_UNUSED(option)
 Q_UNUSED(widget)
   if (m_boundingRect == QRectF())
@@ -196,8 +205,8 @@ Q_UNUSED(widget)
   }
   if (edge()->renderOperations().isEmpty())
   {
-    if ((edge()->fromNode()->canvasElement()!=0)
-      && (edge()->toNode()->canvasElement()!=0))
+    if ((edge()->fromNode()->canvasElement())
+      && (edge()->toNode()->canvasElement()))
     {
       p->drawLine(
         edge()->fromNode()->canvasElement()->boundingRect().center()+edge()->fromNode()->canvasElement()->pos(),
@@ -217,14 +226,14 @@ Q_UNUSED(widget)
 
   foreach (const DotRenderOp& dro, edge()->renderOperations())
   {
-    //     kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "renderop" << dro.renderop << "; selected:" << edge()->isSelected();
+    //     qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "renderop" << dro.renderop << "; selected:" << edge()->isSelected();
     if (dro.renderop == "c")
     {
       QColor c(dro.str.mid(0,7));
       bool ok;
       c.setAlpha(255-dro.str.mid(8).toInt(&ok,16));
       lineColor = c;
-//       kDebug() << "c" << dro.str.mid(0,7) << lineColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "c" << dro.str.mid(0,7) << lineColor;
     }
     else if (dro.renderop == "C")
     {
@@ -236,7 +245,7 @@ Q_UNUSED(widget)
         c = c.lighter();
       }*/
       backColor = c;
-//       kDebug() << "C" << dro.str.mid(0,7) << backColor;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << "C" << dro.str.mid(0,7) << backColor;
     }
     else if ( dro.renderop == "T" )
     {
@@ -267,7 +276,7 @@ Q_UNUSED(widget)
                       + m_xMargin;
       qreal y = ((m_gh - (dro.integers[1]))*m_scaleY)+ m_yMargin;
       QPointF point(x,y);
-//       kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawText" << edge()->fontColor() << point;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawText" << edge()->fontColor() << point;
 
       p->drawText(point,str);
 
@@ -284,14 +293,14 @@ Q_UNUSED(widget)
             (int(m_gh-dro.integers[2*i+2])/*%m_hdvcf*/)*m_scaleY + m_yMargin
                 );
         polygon[i] = point;
-//         kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id()  << point;
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id()  << point;
         allPoints.append(point);
       }
       if (dro.renderop == "P" )
       {
         p->setBrush(lineColor);
         p->drawPolygon(polygon);
-//         kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPolygon" << edge()->color(0) << polygon;
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPolygon" << edge()->color(0) << polygon;
         p->setBrush(oldBrush);
       }
       else
@@ -310,7 +319,7 @@ Q_UNUSED(widget)
         pen.setStyle(Dot2QtConsts::componentData().qtPenStyle(edge()->style()));
       }
       p->setPen(pen);
-//       kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPolyline" << edge()->color(0) << polygon;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPolyline" << edge()->color(0) << polygon;
       p->drawPolyline(polygon);
       p->setPen(oldPen);
       p->setBrush(oldBrush);
@@ -342,7 +351,7 @@ Q_UNUSED(widget)
       }
       p->setPen(pen);
       QRectF rect(x,y,w,h);
-//       kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawEllipse" << edge()->color(0) << rect;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawEllipse" << edge()->color(0) << rect;
       p->drawEllipse(rect);
       p->setPen(oldPen);
       p->setBrush(oldBrush);
@@ -374,7 +383,7 @@ Q_UNUSED(widget)
       }
       if (edge()->attributes().contains("color"))
       {
-        kDebug() << "set edge color to " << QColor(edge()->attributes()["color"]).name();
+        qCDebug(KGRAPHVIEWERLIB_LOG) << "set edge color to " << QColor(edge()->attributes()["color"]).name();
         lineColor = QColor(edge()->attributes()["color"]);
       }
       for (int splineNum = 0; splineNum < edge()->colors().count() || (splineNum==0 && edge()->colors().count()==0); splineNum++)
@@ -385,7 +394,7 @@ Q_UNUSED(widget)
 //         p->setBrush(Dot2QtConsts::componentData().qtColor(edge()->color(0)));
         p->setBrush(Qt::NoBrush);
         p->setPen(pen);
-//         kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPath" << edge()->color(splineNum) << points.first() << points.last();
+//         qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "drawPath" << edge()->color(splineNum) << points.first() << points.last();
         p->drawPath(pathForSpline(splineNum, dro));
         p->setPen(oldPen);
         p->setBrush(oldBrush);
@@ -394,7 +403,7 @@ Q_UNUSED(widget)
   }
   if (edge()->isSelected())
   {
-//     kDebug() << "draw square";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << "draw square";
 //     p->drawRect(m_boundingRect);
     qreal maxDist = 0;
     QPair<QPointF,QPointF> pointsPair;
@@ -424,20 +433,20 @@ Q_UNUSED(widget)
 
 void CanvasEdge::modelChanged()
 {
-//   kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id();
+//   qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id();
   prepareGeometryChange();
   computeBoundingRect();
 }
 
 void CanvasEdge::computeBoundingRect()
 {
-//   kDebug();
+//   qCDebug(KGRAPHVIEWERLIB_LOG);
   //invalidate bounding region cache
   m_shape = QPainterPath();
   if (edge()->renderOperations().isEmpty())
   {
-    if ((edge()->fromNode()->canvasElement()==0)
-      || (edge()->toNode()->canvasElement()==0)
+    if ((edge()->fromNode()->canvasElement() == nullptr)
+      || (edge()->toNode()->canvasElement() == nullptr)
       || edge()->style()=="invis")
     {
       m_boundingRect = QRectF();
@@ -447,7 +456,7 @@ void CanvasEdge::computeBoundingRect()
       QRectF br(
       edge()->fromNode()->canvasElement()->boundingRect().center()+edge()->fromNode()->canvasElement()->pos(),
                 edge()->toNode()->canvasElement()->boundingRect().center()+edge()->toNode()->canvasElement()->pos());
-//       kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() <<br;
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() <<br;
       m_boundingRect = br;
     }
   }
@@ -456,7 +465,7 @@ void CanvasEdge::computeBoundingRect()
     QPolygonF points;
     foreach (const DotRenderOp& dro, edge()->renderOperations())
     {
-//       kDebug() << dro.renderop  << ", ";
+//       qCDebug(KGRAPHVIEWERLIB_LOG) << dro.renderop  << ", ";
       if ( (dro.renderop != "B") && (dro.renderop != "p") &&  (dro.renderop != "P") ) continue;
       uint previousSize = points.size();
       points.resize(previousSize+dro.integers[0]);
@@ -469,7 +478,7 @@ void CanvasEdge::computeBoundingRect()
         points[previousSize+i] = p;
       }
     }
-//     kDebug() << points.size() << "points";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << points.size() << "points";
     if (points.size() == 0) return;
 
     int len = points.count();
@@ -481,16 +490,16 @@ void CanvasEdge::computeBoundingRect()
     {
       a[len+i] = b[i];
     }
-//     kDebug() << a.size() << "points";
+//     qCDebug(KGRAPHVIEWERLIB_LOG) << a.size() << "points";
 
     m_boundingRect = a.boundingRect();
   }
-  kDebug() << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "New bounding rect is:" << m_boundingRect;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->fromNode()->id() << "->" << edge()->toNode()->id() << "New bounding rect is:" << m_boundingRect;
 }
 
 void CanvasEdge::mousePressEvent(QGraphicsSceneMouseEvent * event)
 {
-  kDebug() << event;
+  qCDebug(KGRAPHVIEWERLIB_LOG) << event;
   if (m_view->isReadOnly())
   {
     return;
@@ -512,10 +521,10 @@ void CanvasEdge::mousePressEvent(QGraphicsSceneMouseEvent * event)
       emit(selected(this,event->modifiers()));
       update();
     }
-    kDebug() << "emiting edgeContextMenuEvent("<<m_edge->id()<<","<<event->screenPos()<<")";
+    qCDebug(KGRAPHVIEWERLIB_LOG) << "emiting edgeContextMenuEvent("<<m_edge->id()<<","<<event->screenPos()<<")";
     emit(edgeContextMenuEvent(m_edge->id(), event->screenPos() ));
 // opens the selected edge contextual menu and if necessary select the edge
-/*    kDebug() << "opens the contextual menu";
+/*    qCDebug(KGRAPHVIEWERLIB_LOG) << "opens the contextual menu";
     m_popup->exec(event->screenPos());*/
   }
 }
@@ -527,24 +536,21 @@ qreal CanvasEdge::distance(const QPointF& point1, const QPointF& point2)
 
 void CanvasEdge::slotRemoveEdge()
 {
-  kDebug();
   m_view->removeSelectedElements();
 }
 
 void CanvasEdge::hoverEnterEvent( QGraphicsSceneHoverEvent * event )
 {
   Q_UNUSED(event)
-  kDebug() << edge()->id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->id();
   emit hoverEnter(this);
 }
 
 void CanvasEdge::hoverLeaveEvent( QGraphicsSceneHoverEvent * event )
 {
   Q_UNUSED(event)
-  kDebug() << edge()->id();
+  qCDebug(KGRAPHVIEWERLIB_LOG) << edge()->id();
   emit hoverLeave(this);
 }
 
 }
-
-#include "canvasedge.moc"
